@@ -8,7 +8,11 @@ if __name__ == '__main__':
 
 # TODO 所有的搜搜窗口都不热点捕捉但是置前（不仅仅是F3启动）
 
-from idlelib import search
+import sys
+if sys.version_info > (3, 6):
+    from idlelib.search import _setup
+else:
+    from idlelib.SearchDialog import _setup
 
 
 class QuickSearch:
@@ -18,7 +22,7 @@ class QuickSearch:
         self.text.bind('<Shift-F3>', lambda e: self.FindPrev(True))
 
     def FindPrev(self, back):
-        searchdialog = search._setup(self.text)
+        searchdialog = _setup(self.text)
         searchdialog.engine.backvar.set(back)
         searchdialog.find_again(self.text)
         searchdialog.top.grab_release() # 取消grab_set()窗口置顶
