@@ -198,6 +198,7 @@ class MyEditorWindow(EditorWindow):
 
         self.recent_files_menu['postcommand'] = self.update_recent_files_list  # fix list not refresh when open another IDLE.
 
+        self.text.bind('<ButtonRelease-1>', lambda e: self.text.event_generate('<<set-line-and-column>>')) # fix event can't multi-binding to `ButtonRelease-1`
         self.load_adv_extensions()
         self.text.bind('<F12>', self.test)
 
@@ -222,10 +223,10 @@ class MyEditorWindow(EditorWindow):
             if ext == '.py' and name not in ('__init__', '__main__'):
                 try:
                     self.load_extension(name) # TODO 支持任意位置文件导入
-                except:
-                    print('Failed to import IDLE-Adv extension: %s' % name)
-                    import traceback
-                    traceback.print_exc()
+                except Exception as e:
+                    print("Fail to load extension 'idlealib.%s':\n  %s" % (name, e), file=sys.stderr)
+                    # import traceback
+                    # traceback.print_exc()
 
         menu = self.menudict['advance']
         if menu.type('end') == 'separator':
